<?php

/**
 * @file
 * Contains \Drupal\country_path\HttpKernel\CountryPathProcessor.
 *
 * Created by PhpStorm.
 * User: itsekhmistro
 * Date: 12/17/15
 * Time: 2:01 AM
 */

namespace Drupal\country_path\HttpKernel;

use Drupal\Core\PathProcessor\InboundPathProcessorInterface;
use Drupal\Core\PathProcessor\OutboundPathProcessorInterface;
use Drupal\Core\Render\BubbleableMetadata;
use Symfony\Component\HttpFoundation\Request;
use Drupal\domain\DomainInterface;
use Drupal\domain\DomainNegotiatorInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;


/**
 * Path processor for country_path.
 */
class CountryPathProcessor implements InboundPathProcessorInterface, OutboundPathProcessorInterface {

  /**
   * The DomainNegotiator.
   *
   * @var \Drupal\domain\DomainNegotiatorInterface
   */
  protected $domainNegotiator;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Constructs a DomainPathProcessor object.
   *
   * @param \Drupal\domain\DomainNegotiatorInterface $negotiator
   *   The domain negotiator service.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler service.
   */
  public function __construct(DomainNegotiatorInterface $negotiator, ModuleHandlerInterface $module_handler) {
    $this->domainNegotiator = $negotiator;
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public function processInbound($path, Request $request) {
    static $active_domain;
    if (!isset($active_domain)) {
      $active_domain = $this->domainNegotiator->getActiveDomain();
    }

    // Only act on valid internal paths and when a domain loads.
    if (empty($active_domain) || empty($path) || !empty($options['external'])) {
      return $path;
    }

    $domain_suffix = 'central';
    if (2 == $active_domain->getDomainId()) {
      $domain_suffix = 'usa';
    }

    if (preg_match('/^\/' . $domain_suffix . '/i', $path, $matches)) {
      $path = preg_replace('@^/' . $domain_suffix . '(.*)@', '$1', $path);
    }
    return $path;
  }

  /**
   * {@inheritdoc}
   */
  public function processOutbound($path, &$options = array(), Request $request = NULL, BubbleableMetadata $bubbleable_metadata = NULL) {
    static $active_domain;
    if (!isset($active_domain)) {
      $active_domain = $this->domainNegotiator->getActiveDomain();
    }

    // Only act on valid internal paths and when a domain loads.
    if (empty($active_domain) || empty($path) || !empty($options['external'])) {
      return $path;
    }

    $domain_suffix = 'central';
    if (2 == $active_domain->getDomainId()) {
      $domain_suffix = 'usa';
    }
    if (!preg_match('/^\/' . $domain_suffix . '/i', $path, $matches)) {
      $path = '/' . $domain_suffix . $path;
    }
    return $path;
  }

}
